==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elk/dialogs_nl.lua <==

dialogId("deu-m-valka", "font_small", "The war goes on even here, on the ocean floor.")
dialogStr("De oorlog gaat hier op de oceaanbodem gewoon door.")


dialogId("deu-v-nepratelstvi", "font_big", "The hostility will never ebb.")
dialogStr("De vijanderlijkheden houden nooit op.")


dialogId("deu-m-bojovat", "font_small", "They will fight to the last... parrot.")
dialogStr("Ze zullen doorvechten tot de laatste... papegaai.")


dialogId("deu-v-losa", "font_big", "And elk.")
dialogStr("En eland.")


dialogId("deu-m-zvlastni", "font_small", "Now, this is strange. I thought that elks only live in Sweden.")
dialogStr("Dat is raar. Ik dacht dat elenden alleen in Zweden voorkwamen.")


dialogId("deu-v-slysel", "font_big", "Yes. I too have heard that they bite tourists there.")
dialogStr("Ja. Ik heb ook gehoord dat ze daar touristen bijten.")


dialogId("deu-l-los", "font_elk", "Ya rusky los.")
dialogStr("Ja ruski los.")


dialogId("deu-v-radsi", "font_big", "I`d like this elk much more if it wasn`t blocking our way so much.")
dialogStr("Ik zou deze Eland een stuk liever vinden als hij niet zo in de weg lag.")


dialogId("deu-l-pozalsta", "font_elk", "Pozhalsta, izvinitye.")
dialogStr("Posjhalsta, isvinitjeh.")


dialogId("deu-l-los1", "font_elk", "Chto sluchilos?")
dialogStr("Sjto slutjilos?")


dialogId("deu-l-ja", "font_elk", "Ya los...")
dialogStr("Ja los...")


dialogId("deu-l-neznaju", "font_elk", "Ya nichevo nyeznayu.")
dialogStr("Ja nitsjewoh njesnaju.")


dialogId("deu-l-nesmotrel", "font_elk", "Ya nichevo nyesmotrel.")
dialogStr("Ja nitsjewo njesmotrel.")


dialogId("deu-l-zivjot", "font_elk", "Pustye zhivyot moguchy Sovietsky Soyuz!")
dialogStr("Pustje zjiwsjot mogusji Sovjetski Sojoes!")


dialogId("deu-l-necital", "font_elk", "Ja nichevo nechital.")
dialogStr("Ja nitsjewo njetsjital.")


dialogId("deu-l-tovarisci", "font_elk", "Tovarishchi, bratya i sestri, dorogiye druzya...")
dialogStr("Towarisji, bratja i sjestri, dorogieje drusja...")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elk/dialogs_nl.lua <==

dialogId("deu-m-valka", "font_small", "The war goes on even here, on the ocean floor.")
dialogStr("De oorlog gaat hier op de oceaanbodem gewoon door.")


dialogId("deu-v-nepratelstvi", "font_big", "The hostility will never ebb.")
dialogStr("De vijanderlijkheden houden nooit op.")


dialogId("deu-m-bojovat", "font_small", "They will fight to the last... parrot.")
dialogStr("Ze zullen door vechten tot de laatste... papegaai.")


dialogId("deu-v-losa", "font_big", "And elk.")
dialogStr("En eland.")


dialogId("deu-m-zvlastni", "font_small", "Now, this is strange. I thought that elks only live in Sweden.")
dialogStr("Dat is raar. Ik dacht dat elenden alleen in Zweden voorkwamen.")


dialogId("deu-v-slysel", "font_big", "Yes. I too have heard that they bite tourists there.")
dialogStr("Ja. Ik heb ook gehoord dat ze daar touristen bijten.")


dialogId("deu-l-los", "font_elk", "Ya rusky los.")
dialogStr("Ja ruski los. Ik ben een russische eland.")


dialogId("deu-v-radsi", "font_big", "I’d like this elk much more if it wasn’t blocking our way so much.")
dialogStr("Ik zou deze Eland een stuk aardiger vinden als hij niet zo in de weg lag.")


dialogId("deu-l-pozalsta", "font_elk", "Pozhalsta, izvinitye.")
dialogStr("Posjhalsta, isvinitjeh.")


dialogId("deu-l-los1", "font_elk", "Chto sluchilos?")
dialogStr("Sjto slutjilos?")


dialogId("deu-l-ja", "font_elk", "Ya los...")
dialogStr("Ja los...")


dialogId("deu-l-neznaju", "font_elk", "Ya nichevo nyeznayu.")
dialogStr("Ja nitsjewoh njeznaju.")


dialogId("deu-l-nesmotrel", "font_elk", "Ya nichevo nyesmotrel.")
dialogStr("Ja nitsjewo njesmotrel.")


dialogId("deu-l-zivjot", "font_elk", "Pustye zhivyot moguchy Sovietsky Soyuz!")
dialogStr("Pustje zjiwsjot mogusji Sovjetski Sojoes!")


dialogId("deu-l-necital", "font_elk", "Ja nichevo nechital.")
dialogStr("Ja nitsjewo njetsjital.")


dialogId("deu-l-tovarisci", "font_elk", "Tovarishchi, bratya i sestri, dorogiye druzya...")
dialogStr("Towarisji, bratja i sjestri, dorogieje druzija...")
